aboutsummaryrefslogtreecommitdiff
path: root/modules/ECMOptionalAddSubdirectory.cmake
diff options
context:
space:
mode:
Diffstat (limited to 'modules/ECMOptionalAddSubdirectory.cmake')
-rw-r--r--modules/ECMOptionalAddSubdirectory.cmake12
1 files changed, 6 insertions, 6 deletions
diff --git a/modules/ECMOptionalAddSubdirectory.cmake b/modules/ECMOptionalAddSubdirectory.cmake
index ec0ea30a..e1733bcc 100644
--- a/modules/ECMOptionalAddSubdirectory.cmake
+++ b/modules/ECMOptionalAddSubdirectory.cmake
@@ -1,11 +1,11 @@
# - MACRO_OPTIONAL_ADD_SUBDIRECTORY() combines ADD_SUBDIRECTORY() with an OPTION()
# MACRO_OPTIONAL_ADD_SUBDIRECTORY( <dir> )
# If you use MACRO_OPTIONAL_ADD_SUBDIRECTORY() instead of ADD_SUBDIRECTORY(),
# this will have two effects
# 1 - CMake will not complain if the directory doesn't exist
# This makes sense if you want to distribute just one of the subdirs
# in a source package, e.g. just one of the subdirs in kdeextragear.
-# 2 - If the directory exists, it will offer an option to skip the
+# 2 - If the directory exists, it will offer an option to skip the
# subdirectory.
# This is useful if you want to compile only a subset of all
# directories.
@@ -22,7 +22,7 @@
# For details see the accompanying COPYING-CMAKE-SCRIPTS file.
-MACRO (MACRO_OPTIONAL_ADD_SUBDIRECTORY _dir )
+FUNCTION (ECM_OPTIONAL_ADD_SUBDIRECTORY _dir )
GET_FILENAME_COMPONENT(_fullPath ${_dir} ABSOLUTE)
IF(EXISTS ${_fullPath}/CMakeLists.txt)
IF(DISABLE_ALL_OPTIONAL_SUBDIRECTORIES)
@@ -38,4 +38,4 @@ MACRO (MACRO_OPTIONAL_ADD_SUBDIRECTORY _dir )
ADD_SUBDIRECTORY(${_dir})
ENDIF(BUILD_${_dir})
ENDIF(EXISTS ${_fullPath}/CMakeLists.txt)
-ENDMACRO (MACRO_OPTIONAL_ADD_SUBDIRECTORY)
+ENDFUNCTION (ECM_OPTIONAL_ADD_SUBDIRECTORY)
@@ -1,11 +1,11 @@
-# - MACRO_OPTIONAL_ADD_SUBDIRECTORY() combines ADD_SUBDIRECTORY() with an OPTION()
-# MACRO_OPTIONAL_ADD_SUBDIRECTORY( <dir> )
-# If you use MACRO_OPTIONAL_ADD_SUBDIRECTORY() instead of ADD_SUBDIRECTORY(),
+# - ECM_OPTIONAL_ADD_SUBDIRECTORY() combines ADD_SUBDIRECTORY() with an OPTION()
+# ECM_OPTIONAL_ADD_SUBDIRECTORY( <dir> )
+# If you use ECM_OPTIONAL_ADD_SUBDIRECTORY() instead of ADD_SUBDIRECTORY(),
# this will have two effects
# 1 - CMake will not complain if the directory doesn't exist